@@ -19,12 +19,14 @@ Q_OBJECT
     void goodBye();
     void showSchool();
     void showSchoolSet();
+    void showJyearList();
 
   private:
     CSchoolData *m_pschoolData;
     void LoadData();
     void SaveData();
     boolean OpenDataFile(QFile *pfdata);
+    boolean isQVGA();
 };
 
 #endif
